==> polyxmass-bin_0.8.7.orig.tar.gz: polyxmass-bin-0.8.7/src/polyxedit-ui-fragment-options.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_FRAGMENT_OPTIONS_H
#define POLYXEDIT_UI_FRAGMENT_OPTIONS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "polyxedit-globals.h"
#include "polyxedit-editctxt.h"



GtkWidget *
polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt);


gboolean
polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window, 
					   GtkWidget *vbox);


GtkTreeModel *
polyxedit_fragment_opt_create_fgs_treeview_model (GPtrArray *GPA);


void
polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget, gpointer data);




gboolean
polyxedit_fragment_opt_wnd_delete_event (GtkWidget *widget,
					 GdkEvent *event,
					 gpointer data);

gboolean
polyxedit_fragment_opt_wnd_destroy_event (GtkWidget *widget,
					  GdkEvent *event,
					  gpointer data);









#endif /*POLYXEDIT_UI_FRAGMENT_OPTIONS_H */

==> polyxmass-bin_0.8.9.orig.tar.gz: polyxmass-bin-0.8.9/src/polyxedit-ui-fragment-options.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_FRAGMENT_OPTIONS_H
#define POLYXEDIT_UI_FRAGMENT_OPTIONS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "polyxedit-globals.h"
#include "polyxedit-editctxt.h"



GtkWidget *
polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt);


gboolean
polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window, 
					   GtkWidget *vbox);


GtkTreeModel *
polyxedit_fragment_opt_create_fgs_treeview_model (GPtrArray *GPA);


void
polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget, gpointer data);




/* WINDOW LIFE-CYCLE FUNCTIONS.
 */
void
polyxedit_fragment_opt_wnd_really_close (GtkWidget *window);

gboolean
polyxedit_fragment_opt_wnd_delete_event (GtkWidget *window,
					 GdkEvent *event,
					 gpointer data);

gboolean
polyxedit_fragment_opt_wnd_destroy_event (GtkWidget *window,
					  GdkEvent *event,
					  gpointer data);









#endif /*POLYXEDIT_UI_FRAGMENT_OPTIONS_H */
